#
# NOA Remap Script version 1.1
#
# Script modifies Calling and Called NOA values on outgoing TDM (ISDN, SS7) call legs based on CgPN and CdPN.
# Adding custom columns to the static routing table is required, please see:
# http://support.patton.com/index.php?/patton/Knowledgebase/Article/View/450/
#
# Version history:
#  1.1  (start of version history tracking)
#
# by mpodoski [at] Patton Electronics
#

require 'base_routing'

class NOAremap < BaseRouting
  
  route_match :call_field_name => :called
  route_match :call_field_name => :calling
  route_match :call_field_name => :nap
  route_remap :call_field_name => :called, :route_field_name => :remapped_called
  route_remap :call_field_name => :calling, :route_field_name => :remapped_calling
  route_remap :call_field_name => :nap, :route_field_name => :remapped_nap
  route_remap :method => :noa_remap
  
  def noa_remap ( route, call, naps, call_params )
    napstat=naps[call_params[:nap].to_sym]
    if  napstat[:signaling_type] == "ISDN" || napstat[:signaling_type] == "SS7"
      #Uncomment only for debugging purposes
	  #log_trace 2, "NOA setter: Outgoing TDM NAP detected #{call_params[:nap]}"

      #Static definition of CgNPI
      call_params[:calling_npi] = :isdn
     
      if ( !route[:remap_CgNOA].nil? && route[:remap_CgNOA] != "" )
        call_params[:calling_noa] = route[:remap_CgNOA]
        #Uncomment only for debugging purposes
        #log_trace 2, "NOA setter: Calling NOA set to #{call_params[:calling_noa]}"
      else
        #Uncoment only for debugging purposes
        #log_trace 2, "NOA setter: remap_CgNOA field empty"
      end

      if ( !route[:remap_CdNOA].nil? && route[:remap_CdNOA] != "" )
        call_params[:called_noa] = route[:remap_CdNOA]
        #Uncomment only for debugging purposes
        #log_trace 2, "NOA setter: Called NOA set to #{call_params[:called_noa]}"
      else
        #Uncomment only for debugging purposes
        #log_trace 2, "NOA setter: remap_CdNOA field empty"
      end      

    else
      #Uncomment only for debugging purposes
      #log_trace 2, "NOA setter: non TDM NAP #{call_params[:nap]}"
    end

    call_params
  end
end

@@routing = NOAremap.new

def init_routes( routes )
  @@routing.init routes
end

def route( call, nap_list )
  @@routing.route call, nap_list
end